@@ -422,19 +422,29 @@ class LcBuilder:
         clean_flux = flux
         clean_flux_err = flux_err
         is_short_cadence = cadence <= 300
-        if object_info.prepare_algorithm is not None:
-            clean_time, clean_flux, clean_flux_err = object_info.prepare_algorithm.prepare(object_info, clean_time,
-                                                                                           clean_flux, clean_flux_err)
-        if (is_short_cadence and object_info.smooth_enabled) or (
+        if (object_info.binning > 1) or (object_info.prepare_algorithm) or (is_short_cadence and object_info.smooth_enabled) or (
                 object_info.high_rms_enabled and object_info.initial_mask is None):
             logging.info('================================================')
             logging.info('INITIAL FLUX CLEANING')
             logging.info('================================================')
+        if object_info.binning > 1:
+            bins = len(time) / object_info.binning
+            bin_means, bin_edges, binnumber = stats.binned_statistic(time, flux, statistic='mean',
+                                                                     bins=bins)
+            bin_stds, _, _ = stats.binned_statistic(time, flux, statistic='std', bins=bins)
+            bin_width = (bin_edges[1] - bin_edges[0])
+            bin_centers = bin_edges[1:] - bin_width / 2
+            clean_time = bin_centers
+            clean_flux = bin_means
+            clean_flux_err = bin_stds
+        if object_info.prepare_algorithm is not None:
+            clean_time, clean_flux, clean_flux_err = object_info.prepare_algorithm.prepare(object_info, clean_time,
+                                                                                           clean_flux, clean_flux_err)
         if object_info.high_rms_enabled and object_info.initial_mask is None:
             logging.info('Masking high RMS areas by a factor of %.2f with %.1f hours binning',
                          object_info.high_rms_threshold, object_info.high_rms_bin_hours)
             bins_per_day = 24 / object_info.high_rms_bin_hours
-            dif = time[1:] - time[:-1]
+            dif = clean_time[1:] - clean_time[:-1]
             jumps = numpy.where(dif > 3)[0]
             jumps = numpy.append(jumps, len(clean_time))
             before_flux = clean_flux
@@ -533,7 +543,7 @@ class LcBuilder:
                           auto_detrend_enabled=False, auto_detrend_method="cosine", auto_detrend_ratio=0.25,
                           auto_detrend_period=None, prepare_algorithm=None, reduce_simple_oscillations=False,
                           oscillation_snr_threshold=4, oscillation_amplitude_threshold=0.1, oscillation_ws_scale=60,
-                          oscillation_min_period=0.002, oscillation_max_period=0.2):
+                          oscillation_min_period=0.002, oscillation_max_period=0.2, binning=1):
         mission, mission_prefix, id = MissionLightcurveBuilder().parse_object_id(target_name)
         coords = None if mission is not None else self.parse_coords(target_name)
         cadence = cadence if cadence is not None else self.DEFAULT_CADENCES_FOR_MISSION[mission]
@@ -544,7 +554,7 @@ class LcBuilder:
                                      auto_detrend_method, auto_detrend_ratio, auto_detrend_period, prepare_algorithm,
                                      reduce_simple_oscillations, oscillation_snr_threshold,
                                      oscillation_amplitude_threshold, oscillation_ws_scale, oscillation_min_period,
-                                     oscillation_max_period
+                                     oscillation_max_period, binning
                                      )
         elif mission is not None and file is None and cadence > 300:
             return MissionFfiIdObjectInfo(target_name, sectors, author, cadence, initial_mask, initial_transit_mask,
@@ -554,7 +564,7 @@ class LcBuilder:
                                           auto_detrend_period, prepare_algorithm,
                                           reduce_simple_oscillations, oscillation_snr_threshold,
                                           oscillation_amplitude_threshold, oscillation_ws_scale,
-                                          oscillation_min_period, oscillation_max_period)
+                                          oscillation_min_period, oscillation_max_period, binning)
         elif mission is not None and file is not None:
             return MissionInputObjectInfo(target_name, file, initial_mask, initial_transit_mask,
                                           star_info, outliers_sigma, high_rms_enabled, high_rms_threshold,
@@ -562,7 +572,7 @@ class LcBuilder:
                                           auto_detrend_ratio, auto_detrend_period, prepare_algorithm,
                                           reduce_simple_oscillations, oscillation_snr_threshold,
                                           oscillation_amplitude_threshold, oscillation_ws_scale,
-                                          oscillation_min_period, oscillation_max_period)
+                                          oscillation_min_period, oscillation_max_period, binning)
         elif mission is None and coords is not None and cadence > 300:
             return MissionFfiCoordsObjectInfo(coords[0], coords[1], sectors, author, cadence, initial_mask,
                                               initial_transit_mask, star_info, aperture,
@@ -572,7 +582,7 @@ class LcBuilder:
                                               prepare_algorithm,
                                               reduce_simple_oscillations, oscillation_snr_threshold,
                                               oscillation_amplitude_threshold, oscillation_ws_scale,
-                                              oscillation_min_period, oscillation_max_period)
+                                              oscillation_min_period, oscillation_max_period, binning)
         elif mission is None and file is not None:
             return InputObjectInfo(file, initial_mask, initial_transit_mask, star_info,
                                    outliers_sigma, high_rms_enabled, high_rms_threshold, high_rms_bin_hours,
@@ -580,7 +590,7 @@ class LcBuilder:
                                    auto_detrend_period, prepare_algorithm,
                                    reduce_simple_oscillations, oscillation_snr_threshold,
                                    oscillation_amplitude_threshold, oscillation_ws_scale, oscillation_min_period,
-                                   oscillation_max_period)
+                                   oscillation_max_period, binning)
         else:
             raise ValueError(
                 "Invalid target definition with target_name={}, mission={}, id={}, coords={}, sectors={}, file={}, "
