@@ -44,6 +44,11 @@ class MissionFfiLightcurveBuilder(LightcurveBuilder):
         campaigns = None if object_info.sectors == 'all' or mission != "K2" else object_info.sectors
         quarters = None if object_info.sectors == 'all' or mission != "Kepler" else object_info.sectors
         apertures = {}
+        tpf_search_results = lk.search_targetpixelfile(str(mission_id))
+        for tpf_search_result in tpf_search_results:
+            logging.info("There is data for Mission: %s, Year %.0f, Author: %s, ExpTime: %.0f",
+                         tpf_search_result.mission[0], tpf_search_result.year[0], tpf_search_result.author[0],
+                         tpf_search_result.exptime[0].value)
         if mission_prefix == self.MISSION_ID_KEPLER or mission_prefix == self.MISSION_ID_KEPLER_2:
             source = "tpf"
             lcf_search_results = lk.search_lightcurvefile(str(mission_id), mission=mission, cadence=cadence,
@@ -70,7 +75,6 @@ class MissionFfiLightcurveBuilder(LightcurveBuilder):
                 elif mission_prefix == self.MISSION_ID_KEPLER_2:
                     sector = tpf.campaign
                 apertures[sector] = ApertureExtractor.from_boolean_mask(tpf.pipeline_mask, tpf.column, tpf.row)
-                self.__plot_tpf(self, tpf, sector, tpf.pipeline_mask, sherlock_dir)
             star_info = starinfo.StarInfo(sherlock_id, *self.star_catalogs[mission_prefix].catalog_info(id))
         else:
             source = "eleanor"
@@ -100,11 +104,10 @@ class MissionFfiLightcurveBuilder(LightcurveBuilder):
             for s in star:
                 datum = TargetData(s, height=CUTOUT_SIZE, width=CUTOUT_SIZE, do_pca=True)
                 data.append(datum)
-                apertures[s.sector] = ApertureExtractor.from_boolean_mask(datum.aperture.astype(bool),
-                                                                          s.position_on_chip[1], s.position_on_chip[0])
                 for tpf in tpfs:
                     if tpf.sector == s.sector:
-                        self.__plot_tpf(tpf, tpf.sector, datum.aperture.astype(bool), sherlock_dir)
+                        apertures[s.sector] = ApertureExtractor.from_boolean_mask(datum.aperture.astype(bool),
+                                                                                  tpf.column, tpf.row)
             quality_bitmask = np.bitwise_and(data[0].quality.astype(int), 175)
             lc_data = self.extract_eleanor_lc_data(data)
             lc = data[0].to_lightkurve(data[0].__dict__[object_info.eleanor_corr_flux],
