@@ -34,6 +34,11 @@ class MissionLightcurveBuilder(LightcurveBuilder):
         tokens = sectors if sectors is not None else campaigns if campaigns is not None else quarters
         tokens = tokens if tokens is not None else "all"
         apertures = {}
+        tpf_search_results = lk.search_targetpixelfile(str(mission_id))
+        for tpf_search_result in tpf_search_results:
+            logging.info("There is data for Mission: %s, Year %.0f, Author: %s, ExpTime: %.0f",
+                         tpf_search_result.mission[0], tpf_search_result.year[0], tpf_search_result.author[0],
+                         tpf_search_result.exptime[0].value)
         if object_info.apertures is None:
             lcf_search_results = lk.search_lightcurve(str(mission_id), mission=mission, cadence=cadence,
                                            sector=sectors, quarter=quarters,
@@ -57,16 +62,15 @@ class MissionLightcurveBuilder(LightcurveBuilder):
                     sector = tpf.sector
                 if mission_prefix == self.MISSION_ID_KEPLER_2:
                     sector = tpf.campaign
-                self.__plot_tpf(tpf, sector, tpf.pipeline_mask, sherlock_dir)
                 apertures[sector] = ApertureExtractor.from_boolean_mask(tpf.pipeline_mask, tpf.column, tpf.row)
-            for i in range(0, len(lcf.PDCSAP_FLUX)):
-                if lcf.PDCSAP_FLUX[i].label == mission_id:
+            for i in range(0, len(lcf.data)):
+                if lcf.data[i].label == mission_id:
                     if lc is None:
-                        lc = lcf.PDCSAP_FLUX[i].normalize()
+                        lc = lcf.data[i].normalize()
                     else:
-                        lc = lc.append(lcf.PDCSAP_FLUX[i].normalize())
+                        lc = lc.append(lcf.data[i].normalize())
                 else:
-                    matching_objects.append(lcf.PDCSAP_FLUX[i].label)
+                    matching_objects.append(lcf.data[i].label)
             matching_objects = set(matching_objects)
             if len(matching_objects) > 0:
                 logging.warning("================================================")
@@ -107,7 +111,6 @@ class MissionLightcurveBuilder(LightcurveBuilder):
                     sector = tpf.campaign
                 boolean_aperture = ApertureExtractor.from_pixels_to_boolean_mask(apertures[sector], tpf.column, tpf.row,
                                                                          CUTOUT_SIZE, CUTOUT_SIZE)
-                self.__plot_tpf(tpf, sector, boolean_aperture, sherlock_dir)
                 tpf.plot(aperture_mask=boolean_aperture, mask_color='red')
                 plt.savefig(sherlock_dir + "/fov/Aperture_[" + str(sector) + "].png")
                 plt.close()
@@ -174,14 +177,6 @@ class MissionLightcurveBuilder(LightcurveBuilder):
             lc_data = None
         return LcBuild(lc, lc_data, star_info, transits_min_count, cadence, None, sectors, source, apertures)
 
-    def __plot_tpf(self, tpf, sector, aperture, dir):
-        dir = dir + "/fov/"
-        if not os.path.exists(dir):
-            os.mkdir(dir)
-        tpf.plot_pixels(aperture_mask=aperture)
-        plt.savefig(dir + "/Flux_pixels[" + str(sector) + "].png")
-        plt.close()
-
     def __calculate_transits_min_count(self, len_data):
         return 1 if len_data == 1 else 2
 
